/**************************************************************************************************
	Developed by: Colorado Health Institute (CHI)
	Contact Information: 
		Rebecca Silvernale
		720.382.7086
		silvernaler@coloradohealthinstitute.org

	The following is code used to assign formats to the variables in the 2015 Colorado
	Health Access Survey (CHAS) Public Use File. The code was written in SAS format but can be
	modified for use in other applications, such as SPSS or STATA.

	INPUT: CHAS2015_PUF.<ext>
	OUTPUT: A data file compatible with the user's computer system, with formats

***************************************************************************************************/

* provide name and pathname for data file;
%let datafile = /*<USER INPUT>*/ ;

proc format library=;
	value puf_gender
		-9 = "Don't Know/Refused"
		1 = "Male"
		2 = "Female"
	;
	value puf_age
		-9 = "Don't Know/Refused"
		1 = "0 to 18"
		2 = "19 to 34"
		3 = "35 to 54"
		4 = "55 to 64"
		5 = "65 and older"
	;
	value puf_educ
		-9 = "Don't Know/Refused"
		1 = "Less than high school"
		2 = "High school graduate or equivalent"
		3 = "Some college but no degree"
		4 = "Associates Degree"
		5 = "College graduate"
		6 = "Postgraduate"
	;
	value married
		0 = "Not married"
	  	1 = "Married"
	;
	value puf_yn
		-9 = "Don't Know/Refused"
		1 = "Yes"
		2 = "No"
	;
	value puf_urban
		-9 = "Don't Know/Refused"
		0 = "Rural"
		1 = "Urban"
	;
	value noins_tm
		-9 = "Don't Know/Refused"
		1 = "0 to 11 months"
		2 = "12 months"
	;
	value tm_without
		-9 = "Don't Know/Refused"
		1 = "0 to 24 months"
		2 = "More than 24 months"
	;
	value noins_reason
		-9 = "Don't Know/Refused"
		1 = "Cost is too high"
		2 = "Other"
	;
	value puf_hours
		-9 = "Don't Know/Refused"
		1 = "Less than 40 hours/week"
		2 = "40 hours/week"
		3 = "More than 40 hours/week"
	;
	value emp_tm
		-9 = "Don't Know/Refused"
		1 = "Less than1 year"
		2 = "1 to 5 years"
		3 = "6 to 10 years"
		4 = "11 to 20 years"
		5 = "More than 20 years"
	;
	value puf_sz
		-9 = "Don't Know/Refused"
		1 = "1 to 10 employees"
		2 = "11 to 50 employees"
		3 = "51 to 100 employees"
		4 = "More than 100 employees"
	;
	value puf_usoc
		-9 = "Don't Know/Refused"
		1 = "Doctor's office or private clinic"
		2 = "Community health center or other public clinic"
		3 = "Emergency room or urgent care center"
		4 = "Other place"
	;
	value num_people
		-9 = "Don't Know/Refused"
		1 = "1 person"
		2 = "2 people"
		3 = "3 people"
		4 = "4 people"
		5 = "5+ people"
	;
	value live
		-9 = "Don't Know/Refused"
		1 = "0-10 years"
		2 = "11-20 years"
		3 = "20+ years"
	;
	value puf_oop
		-9 = "Don't Know/Refused"
		1 = "$0"
		2 = "$1 to <$200"
		3 = "$200 to <$500"
		4 = "$500 to <$1000"
		5 = "$1000 or more"
	;
	value puf_visits
		-9 = "Don't Know/Refused"
		1 = "None"
		2 = "1 time"
		3 = "2 or more times"
	;
	value home
		-9 = "Don't Know/Refused"
		1 = "Owned"
		2 = "Rented"
	;
	value puf_incyr
		-9 = "Don't Know/Refused"
		1 = "$0 to $29,999"
		2 = "$30,000 to $59,999"
		3 = "$60,000 to $89,999"
		4 = "$90,000 or more"
	;
	value puf_incmon
		-9 = "Don't Know/Refused"
		1 = "$0 to $1,999"
		2 = "$2,000 to $3,999"
		3 = "$4,000 to $5,999"
		4 = "$6,000 or more"
	;
	value puf_ins
		1 = "Employer-sponsored insurance"
		2 = "Medicare"
		3 = "Medicaid/Child Health Plan Plus (CHP+)"
		4 = "Individually purchased insurace/other insurancer"
		5 = "Uninsured"
	;
	value puf_2ins
		1 = "Underinsured"
		2 = "Adequately insured"
		3 = "Insured but uninsured at some point in the past 12 months"
		4 = "Uninsured at time of survey"
		5 = "Insured but with uninsured family member"
	;
	value puf_employ
		-9 = "Don't Know/Refused"
		1 = "Self-employed"
		2 = "Employed by someone else (inc military)"
		3 = "Retired"
		4 = "Unemployed and looking for work"
		5 = "Not employed/unpaid worker"
		6 = "Unable to work because of a disability"
	;
	value white
		-9 = "Don't Know/Refused"
		1 = "White"
		2 = "Non-White"
	;
	value willing2pay
		0 = "$0 to $49"
		1 = "$50 to $99"
	  	2 = "$100 to $149"
	 	3 = "$150 to $199"
	 	4 = "$200 or more"
	;
	value reform
		-9 = "Don't Know/Refused"
	  	1 = "Strongly agree"
	  	2 = "Somewhat agree"
	 	3 = "Somewhat disagree"
	  	4 = "Strongly disagree"
	;
	value puf_health
		-9 = "Don't Know/Refused"
		1 = "Excellent"
		2 = "Very Good"
		3 = "Good"
		4 = "Fair"
		5 = "Poor"
	;
	value spanish
		1="Speak Spanish"
		0="Does not speak Spanish"
	;
	value spk_other
		1="Speak language other than Spanish"
		0="Does not speak a language other than Spanish"
	;
	value ins_pit
		0 = "Does not have insurance"
		1 = "Currently has insurance"
	;
	value puf_underins
		0 = "NOT Underinsured"
		1 = "Underinsured"
	;
	value puf_mh
		-9 = "Don't Know/Refused"
		0 = "Less than 8 days of poor mental health"
		1 = "8 or more days of poor mental health"
	;
	value puf_likely
		-9 = "Don't Know/Refused"
		1 = "Likely"
		2 = "Unlikely"
	;
	value puf_conf
		-9 = "Don't KNow/Refused"
		1 = "Confident"
		2 = "Not Confident"
	;
run;
run;


proc datasets library = ;
	modify &datafile.;

	format AGE_GRP puf_age.;
	format CONF_COINSURANCE puf_conf.;
	format CONF_COPAYMENT puf_conf.;
	format CONF_DEDUCTIBLE puf_conf.;
	format CONF_PREMIUM puf_conf.;
	format COST_NODENT puf_yn.;
	format COST_NODOC puf_yn.;
	format COST_NORX puf_yn.;
	format COST_NOSPEC puf_yn.;
	format DENTAL_INS puf_yn.;
	format DENTIST_12M puf_yn.;
	format DOC_12M puf_visits.;
	format DOC_PREV puf_yn.;
	format EDUCATION puf_educ.;
	format EMPLOYED puf_yn.;
	format EMP_ADDJOB puf_yn.;
	format EMP_CATEGORY puf_employ.;
	format EMP_HRS_WK puf_hours.;
	format EMP_TIME emp_tm.;
	format ER_12M puf_visits.;
	format ER_NOEMER puf_yn.;
	format ER_RES1 puf_yn.;
	format ER_RES2 puf_yn.;
	format ER_RES3 puf_yn.;
	format ER_RES4 puf_yn.;
	format ESI_DEP puf_yn.;
	format ESI_OFFERED puf_yn.;
	format FIRM_ESI puf_yn.;
	format FIRM_SIZE puf_sz.;
	format GENDER puf_gender.;
 	format hc_needs_co reform.;
 	format hc_needs_fam reform.;
	format HEALTH_STATUS puf_health.;
	format HLIT_PLANCOVER puf_likely.;
	format HLIT_SERVICECOVER puf_likely.;
	format HLIT_REVIEW puf_likely.;
	format HLIT_INNETWORK puf_likely.;
	format HOME_OWNER home.;
	format INC_2014_GRP puf_incyr.;
	format INC_DIVIDEND puf_yn.;
	format INC_MON_GRP puf_incmon.;
	format INC_OTH puf_yn.;
	format INC_SALARY puf_yn.;
	format INSURANCE puf_ins.;
	format INSURANCE2 puf_2ins.;
	format INSURED_PIT ins_pit.;
	format LIMIT_ACTIVITY puf_yn.;
	format LSOT_COVERAGE puf_yn.;
	format MARRIED married.;
	format NEEDED_MH puf_yn.;
	format NOCARE_APP puf_yn.;
	format NOCARE_INS puf_yn.;
	format NOCARE_NEWPT puf_yn.;
	format NOCARE_TRANS puf_yn.;
	format NOCARE_WORK puf_yn.;
	format NOCARE_WORK_PAR puf_yn.;
	format NOCARE_CHILDCARE puf_yn.;
	format NOCARE_UNINS puf_yn.;
	format NOINS_12M puf_yn.;
	format NOINS_NUM noins_tm.;
	format NOINS_REASON noins_reason.;
	format NUM_FAM num_people.;
	format NUM_HH num_people.;
	format OOP_DENTAL_GRP puf_oop.;
	format OOP_OTH_GRP puf_oop.;
	format OOP_RX_GRP puf_oop.;
	format ORAL_HEALTH_STATUS puf_health.;
	format POOR_MH puf_mh.;
	format PROB_PAYING puf_yn.;
	format SPEAK_ADD puf_yn.;
	format SPK_SPANISH spanish.;
	format SPK_OTHER spk_other.;
	format SPEC_12M puf_yn.;
	format TIME_LASTCVRD tm_without.;
	format UNDERINS puf_underins.;
	format URBAN puf_urban.;
	format USOC puf_yn.;
	format USOC_TYPE puf_usoc.;
	format VISIT_12M puf_yn.;
	format WELL_PROTECTED reform.;
	format WHITE white.;
	format WILLING2PAY willing2pay.;

quit;

